document.addEventListener('DOMContentLoaded', () => {
  const bodyMap = document.getElementById('bodyMap');
  const selectedTargets = document.getElementById('selectedTargets');
  const queryForm = document.getElementById('queryForm');
  const results = document.getElementById('results');
  const recommendationsList = document.getElementById('recommendationsList');

  // Sample body parts data
  const bodyParts = [
    'Brain', 'Heart', 'Liver', 'Kidneys', 'Lungs',
    'Muscles', 'Bones', 'Skin', 'Blood', 'Immune System'
  ];

  // Create interactive body map
  bodyParts.forEach(part => {
    const element = document.createElement('div');
    element.className = 'body-part';
    element.textContent = part;
    element.setAttribute('data-selected', 'false');
    
    element.addEventListener('click', () => toggleSelection(element, part));
    
    bodyMap.appendChild(element);
  });

  function toggleSelection(element, part) {
    const isSelected = element.getAttribute('data-selected') === 'true';
    element.setAttribute('data-selected', !isSelected);
    element.style.backgroundColor = !isSelected ? '#3498db' : '';
    element.style.color = !isSelected ? 'white' : '';
    
    updateSelectedList();
  }

  function updateSelectedList() {
    selectedTargets.innerHTML = '';
    const selected = document.querySelectorAll('[data-selected="true"]');
    
    selected.forEach(item => {
      const li = document.createElement('li');
      li.textContent = item.textContent;
      selectedTargets.appendChild(li);
    });
  }

  queryForm.addEventListener('submit', (e) => {
    e.preventDefault();
    
    const selectedParts = Array.from(document.querySelectorAll('[data-selected="true"]'))
      .map(el => el.textContent);
    
    if (selectedParts.length === 0) {
      alert('Please select at least one target area');
      return;
    }

    const projectType = document.getElementById('projectType').value;
    const deliveryNeeds = document.getElementById('deliveryNeeds').value;

    // Generate recommendations (mock data)
    const recommendations = generateRecommendations(selectedParts, projectType, deliveryNeeds);
    
    displayResults(recommendations);
  });

  function generateRecommendations(targets, projectType, needs) {
    // Mock recommendation generation
    return targets.map(target => ({
      target,
      solution: `Optimized delivery system for ${target.toLowerCase()}`,
      efficiency: Math.floor(Math.random() * 30 + 70) + '%',
      approach: `Custom ${projectType} approach`
    }));
  }

  function displayResults(recommendations) {
    results.classList.remove('hidden');
    recommendationsList.innerHTML = '';
    
    recommendations.forEach(rec => {
      const div = document.createElement('div');
      div.className = 'recommendation-card';
      div.innerHTML = `
        <h3>${rec.target}</h3>
        <p><strong>Solution:</strong> ${rec.solution}</p>
        <p><strong>Efficiency:</strong> ${rec.efficiency}</p>
        <p><strong>Approach:</strong> ${rec.approach}</p>
      `;
      recommendationsList.appendChild(div);
    });
    
    results.scrollIntoView({ behavior: 'smooth' });
  }
});